@@ -121,7 +121,7 @@ KWalletD::KWalletD()
 	        SIGNAL(serviceOwnerChanged(QString,QString,QString)),
 	        SLOT(slotServiceOwnerChanged(QString,QString,QString)));
 	_dw = new KDirWatch(this );
-		_dw->setObjectName( "KWallet Directory Watcher" );
+		_dw->setObjectName( QLatin1String( "KWallet Directory Watcher" ) );
 	_dw->addDir(KGlobal::dirs()->saveLocation("kwallet"));
 	_dw->startScan(true);
 	connect(_dw, SIGNAL(dirty(const QString&)), this, SLOT(emitWalletListDirty()));
@@ -161,14 +161,14 @@ QPair<int, KWallet::Backend*> KWalletD::findWallet(const QString& walletName) co
     return qMakePair(-1, static_cast<KWallet::Backend*>(0));
 }
 
+bool KWalletD::_processing = false;
+
 void KWalletD::processTransactions() {
-	static bool processing = false;
-	
-	if (processing) {
+	if (_processing) {
 		return;
 	}
 
-	processing = true;
+	_processing = true;
 
 	// Process remaining transactions
 	while (!_transactions.isEmpty()) {
@@ -233,7 +233,7 @@ void KWalletD::processTransactions() {
 		_curtrans = 0;
 	}
 
-	processing = false;
+	_processing = false;
 }
 
 
@@ -352,11 +352,11 @@ int KWalletD::doTransactionOpen(const QString& appid, const QString& wallet, boo
                                 qlonglong wId, bool modal, const QString& service) {
 	if (_firstUse && !wallets().contains(KWallet::Wallet::LocalWallet()) && !isPath) {
 		// First use wizard
-		KWalletWizard *wiz = new KWalletWizard(0);
+		QPointer<KWalletWizard> wiz = new KWalletWizard(0);
 		wiz->setWindowTitle(i18n("KDE Wallet Service"));
 		setupDialog( wiz, (WId)wId, appid, modal );
 		int rc = wiz->exec();
-		if (rc == QDialog::Accepted) {
+		if (rc == QDialog::Accepted && wiz) {
 			bool useWallet = wiz->field("useWallet").toBool();
 			KConfig kwalletrc("kwalletrc");
 			KConfigGroup cfg(&kwalletrc, "Wallet");
@@ -441,7 +441,7 @@ int KWalletD::internalOpen(const QString& appid, const QString& wallet, bool isP
 				}
 				brandNew = false;
 				// don't use KStdGuiItem::open() here which has trailing ellipsis!
-				kpd->setButtonGuiItem(KDialog::Ok,KGuiItem( i18n( "&Open" ), "document-open"));
+				kpd->setButtonGuiItem(KDialog::Ok,KGuiItem( i18n( "&Open" ), "wallet-open"));
 				kpd->setCaption(i18n("KDE Wallet Service"));
 				kpd->setPixmap(KIcon("kwalletmanager").pixmap(KIconLoader::SizeHuge));
 				if (w != KWindowSystem::activeWindow() && w != 0L) {
@@ -686,7 +686,7 @@ void KWalletD::doTransactionChangePassword(const QString& appid, const QString&
 
 	bool reclose = false;
 	if (!w) {
-		handle = doTransactionOpen(appid, wallet, false, wId, false, false);
+		handle = doTransactionOpen(appid, wallet, false, wId, false, "");
 		if (-1 == handle) {
 			KMessageBox::sorryWId((WId)wId, i18n("Unable to open wallet. The wallet must be opened in order to change the password."), i18n("KDE Wallet Service"));
 			return;
@@ -698,12 +698,12 @@ void KWalletD::doTransactionChangePassword(const QString& appid, const QString&
 
 	assert(w);
 
-	KNewPasswordDialog *kpd = new KNewPasswordDialog();
+	QPointer<KNewPasswordDialog> kpd = new KNewPasswordDialog();
 	kpd->setPrompt(i18n("<qt>Please choose a new password for the wallet '<b>%1</b>'.</qt>", Qt::escape(wallet)));
 	kpd->setCaption(i18n("KDE Wallet Service"));
 	kpd->setAllowEmptyPasswords(true);
 	setupDialog( kpd, (WId)wId, appid, false );
-	if (kpd->exec() == KDialog::Accepted) {
+	if (kpd->exec() == KDialog::Accepted && kpd) {
 		QString p = kpd->password();
 		if (!p.isNull()) {
 			w->setPassword(p.toUtf8());
@@ -813,7 +813,7 @@ QStringList KWalletD::wallets() const {
 
 	foreach (const QFileInfo &fi, dir.entryInfoList()) {
 		QString fn = fi.fileName();
-		if (fn.endsWith(".kwl")) {
+		if (fn.endsWith(QLatin1String(".kwl"))) {
 			fn.truncate(fn.length()-4);
 		}
 		rc += fn;
@@ -1458,4 +1458,52 @@ void KWalletD::activatePasswordDialog()
 	}
 }
 
+int KWalletD::pamOpen(const QString &wallet, const QByteArray &passwordHash, int sessionTimeout)
+{
+   // don't do anything if transactions are already being processed!
+   if (_processing) {
+      return -1;
+   }
+   
+   // check if the wallet is already open
+   QPair<int, KWallet::Backend*> walletInfo = findWallet(wallet);
+   int rc = walletInfo.first;
+   if (rc == -1) {
+      if (_wallets.count() > 20) {
+         kDebug() << "Too many wallets open.";
+         return -1;
+      }
+      
+      if (!QRegExp("^[\\w\\^\\&\\'\\@\\{\\}\\[\\]\\,\\$\\=\\!\\-\\#\\(\\)\\%\\.\\+\\_\\s]+$").exactMatch(wallet) ||
+          !KWallet::Backend::exists(wallet)) {
+         return -1;
+      }
+      
+      KWallet::Backend *b = new KWallet::Backend(wallet);
+      int openrc = b->openPreHashed(passwordHash);
+      if (openrc == 0 && b->isOpen()) {
+         // opening the wallet was successful
+         int handle = generateHandle();
+         _wallets.insert(handle, b);
+         _syncTimers.addTimer(handle, _syncTime);
+         
+         // don't reference the wallet or add a session so it
+         // can be reclosed easily.
+         
+         if (sessionTimeout > 0) {
+            _closeTimers.addTimer(handle, sessionTimeout);
+         } else if (_closeIdle) {
+            _closeTimers.addTimer(handle, _idleTime);
+         }
+         emit walletOpened(wallet);
+         if (_wallets.count() == 1 && _launchManager) {
+            KToolInvocation::startServiceByDesktopName("kwalletmanager-kwalletd");
+         }
+         return handle;
+      }
+   }
+   
+   return -1;
+}
+
 #include "kwalletd.moc"
