@@ -37,7 +37,6 @@ DeviceActionsDialog::DeviceActionsDialog(QWidget *parent)
     setModal(false);
     setButtons(Ok|Cancel);
     setDefaultButton(Ok);
-    showButtonSeparator(true);
 
     QWidget *page = new QWidget(this);
     m_view.setupUi(page);
@@ -128,7 +127,7 @@ void DeviceActionsDialog::slotOk()
 void DeviceActionsDialog::launchAction(DeviceAction *action)
 {
     action->execute(m_device);
-    close();
+    accept();
 }
 
 #include "deviceactionsdialog.moc"
